<?php

namespace Drupal\webform_browserinfo\Plugin\WebformElement;

use Drupal\Component\Render\HtmlEscapedText;
use Drupal\webform\Plugin\WebformElementBase;
use Drupal\webform\WebformSubmissionInterface;

/**
 * Provides the Webform Browserinfo element.
 *
 * @WebformElement(
 *   id = "webform_browserinfo",
 *   label = @Translation("Webform Browserinfo"),
 *   description = @Translation("Provides a hidden field containing information about the browser and operating system of the user."),
 *   category = @Translation("Advanced elements"),
 * )
 */
class WebformBrowserinfo extends WebformElementBase {

  /**
   * {@inheritdoc}
   */
  public function prepare(array &$element, ?WebformSubmissionInterface $webform_submission = NULL) {
    parent::prepare($element, $webform_submission);
    $element['#type'] = 'hidden';
    $element['#attributes']['class'][] = 'webform-browserinfo';
    $element['#attributes']['value'] = "No info could be fetched, since JavaScript was disabled.";
    $element['#attached']['library'][] = 'webform_browserinfo/webform-browserinfo';
  }

  /**
   * {@inheritdoc}
   */
  protected function formatHtmlItem(array $element, WebformSubmissionInterface $webform_submission, array $options = []) {
    $value = $this->getValue($element, $webform_submission, $options);

    return [
      '#markup' => nl2br(new HtmlEscapedText($value)),
    ];
  }

}
